-- MonLogiciel.applescript

--  Created by Alain Le Gallou on 10/12/07.  v0.104
-- Support du tutoriel décrit à http://www.legallou.com/Mac/ASS/ASSindex.html

global notesDataSource -- Data Source référence 
global cancel
global OK

property nomFichierPlist : "com.legallou.MonLogiciel.plist"
property dossierRacine : missing value -- Chemin d'accès à l'application 
property cheminBibliothequePreferenceUtilisateur : missing value -- "iMac:Users:alg:Library:Preferences:"
property nomDuFichierPlistPreferenceUtilisateur : missing value --"iMac:Users:alg:Library:Preferences:com.legallou.MonLogiciel.plist"



on awake from nib theObject --------------------------------------
	
	if the name of theObject is "Main" then
		log "Main"
		load_Notes() -- Chargement de toutes les notes		
		--hide window "Input"
		--Notes_Init_Data() -- pour debugging et ré-initialisation	
	end if
	
end awake from nib --------------------------------------




on clicked theObject --------------------------------------
	
	-- Les deux boutons de la fenêtre "Input"
	if (the name of theObject is "AjouterInput") then routine_AjouterInput()
	if (the name of theObject is "CancelInput") then hide window "Input"
	
	
	
	-- Si l'objet est le tableau
	-- Suppression d'une rangée sélectionnée si la touche option est enfonçée 
	if (the name of theObject is "notesTableView") then
		
		if (the option key down of event 1 is true) then
			
			set notesTablePointeur to table view "notesTableView" of scroll view "notesScrollView" of window "Main"
			-- Le résultat est "table view id 4 of scroll view id 3 of window id 1"
			
			set selectedDataRows to selected data rows of notesTablePointeur
			-- Le résultat est "{data row id 19 of data source id 12}"
			
			if (count of selectedDataRows) > 0 then
				
				delete (item 1 of selectedDataRows) -- item 1 obligatoire c'est une liste				
			end if
		end if
	end if -----------------------------------------
	
	
end clicked --------------------------------------



on choose menu item theObject -------------- Gére la barre des Menus --------------------
	
	log "choose menu item"
	
	if name of theObject is "Importer" then display dialog "Not done" -- routine_Importer()
	
	if name of theObject is "Exporter" then display dialog "Not done" -- routine_Exporter()
	
	if name of theObject is "Ajouter une ligne" then routine_AddOneNote()
	
	if name of theObject is "Suppression de lignes" then routine_DeleteNote()
	
	
end choose menu item ----------------------------------------------------




on should quit theObject --- Exécuté à la fermeture de  l'application -----
	log "should quit"
	stockerAllNotesInPlist() -- Ecriture de la data source "Notes" dans l'entrée "NotesToutes" de la P-list 	
end should quit ---------------------------------------------------





on column clicked theObject table column tableColumn -------------------------
	--TRI d'une colonne avec inversion de ascending descending ---
	-- Tri de celle qui a été cliquée - programme standard Apple
	-- Voir AppleScript Studio exemple dans "table sort"
	
	-- Obtention de la data source du tableau
	set theDataSource to data source of theObject
	
	-- Obtention de l'identifiant de la colonne cliquée
	set theColumnIdentifier to identifier of tableColumn
	
	-- Quelle est la colonne de tri actuelle dans la data source
	set theSortColumn to sort column of theDataSource
	
	-- Si la colonne de tri n'est pas celle cliquée, inverser les colonnes
	if (name of theSortColumn) is not equal to theColumnIdentifier then
		set the sort column of theDataSource to data column theColumnIdentifier of theDataSource
	else
		-- Changement de l'ordre du tri
		if sort order of theSortColumn is ascending then
			set sort order of theSortColumn to descending
		else
			set sort order of theSortColumn to ascending
		end if
	end if
	
	-- Pour redessiner le tableau executer la commande update
	update theObject
	
	set selected rows of theObject to {0} -- Pour enlever le fond bleue 
	
end column clicked ---------------------------------------------------




(* ==== Gestion du tableau "Notes" initialisation, data source création ====== *)



on load_Notes() ----------------------------------------------------------------------------
	-----  Chargement à partir de la p-list "com.legallou.MonLogiciel.plist" ------   	
	log "load_Notes"
	tell user defaults
		set ListeDeToutesLesNotes to contents of default entry "NotesToutes" as list
	end tell
	Creation_DataSource_Notes(ListeDeToutesLesNotes) -- Create & load Data Source
	
end load_Notes ----------------------------------------------------------------------------




on Creation_DataSource_Notes(la_liste) --------- création de la data source et initialisation -----------
	log "Creation_DataSource_Notes"
	-- Nous allons définir une "data source" pour stocker en mémoire RAM les données du tableau --
	-- En premier, nous définissons un pointeur sur l'objet tableau sur lequel nous allons travailler --
	set NotesObject to table view "notesTableView" of scroll view "notesScrollView" of window "Main"
	
	-- Maintenant nous définissons une "data source" associée à ce tableau --
	-- elle sera ajouter au autre data source déjà existante --
	-- On lui donne un nom pour la gestion interne --
	set notesDataSource to make new data source at end of data sources with properties {name:"notesDS"}
	
	-- Création des colonnes de données, incluant l'information de tri pour chaque colonne --
	make new data column at end of data columns of notesDataSource with properties {name:"Name", sort order:ascending, sort type:alphabetical, sort case sensitivity:case insensitive}
	make new data column at end of data columns of notesDataSource with properties {name:"Description", sort order:ascending, sort type:alphabetical, sort case sensitivity:case insensitive}
	make new data column at end of data columns of notesDataSource with properties {name:"Date", sort order:ascending, sort type:alphabetical, sort case sensitivity:case sensitive}
	make new data column at end of data columns of notesDataSource with properties {name:"Prix", sort order:ascending, sort type:numerical, sort case sensitivity:case sensitive}
	make new data column at end of data columns of notesDataSource with properties {name:"Col5", sort order:ascending, sort type:alphabetical, sort case sensitivity:case insensitive}
	make new data column at end of data columns of notesDataSource with properties {name:"Col6", sort order:ascending, sort type:alphabetical, sort case sensitivity:case insensitive}
	
	-- Précisons que nous voulons trier les colonnes
	set sorted of notesDataSource to true -- La "data source" est triée
	
	-- Définition de la colonne de tri initiale --
	set sort column of notesDataSource to data column "Name" of notesDataSource
	
	-- Finallement, relions la "data source" au tableau --
	set data source of NotesObject to notesDataSource -- tableau "notesTableView"
	
	-- Stockage, par remplacement, des données dans la data source --
	append notesDataSource with la_liste
	
end Creation_DataSource_Notes ----------------------------------------------






on stockerAllNotesInPlist() ---- Ecriture de la data source "Notes" dans l'entrée "NotesToutes" de la P-list  
	log "stockerAllNotesInPlist"
	---- Récupérons les données du tableau (Data Source) -----	
	set mesNotes to content of contents of notesDataSource as list -- Les données
	
	tell user defaults
		--  Création une entrée dans de la p-list, si elle n'existe pas elle sera créée 
		-- Si elle existe déjà la commande ne génére pas d'erreur
		make new default entry at end of default entries with properties {name:"NotesToutes", contents:mesNotes}
		
		-- Stockage des données dans la p-list
		set contents of default entry "NotesToutes" to mesNotes
	end tell
	
	return true
	
end stockerAllNotesInPlist -----------------------------------------------



(* ==================================================== *)






(* ==================== Handler généraux =================== *)


on stockerUneLigne(leNom, laDescription, laDate, lePrix, laCol5, LaCol6)
	
	log "stockerUneLigne" -- Trace pour la mise au point
	
	-- Initialiser une nouvelle rangée dans la data source
	set nouvelRange to make new data row at the end of the data rows of notesDataSource
	
	-- Transférer les données des champs vers la nouvelle rangée
	set contents of data cell "Name" of the nouvelRange to leNom
	set contents of data cell "Description" of the nouvelRange to laDescription
	set contents of data cell "Date" of the nouvelRange to laDate
	set contents of data cell "Prix" of the nouvelRange to lePrix as number
	set contents of data cell "Col5" of the nouvelRange to laCol5
	set contents of data cell "Col6" of the nouvelRange to LaCol6
	
	-- Ecriture dans la data source
	tell table view "notesTableView" of scroll view "notesScrollView" of the window "Main" to update
	
end stockerUneLigne ------------------------------------------------------------





on routine_DeleteNote() ------------- Suppression multiple -----------------	
	
	log "routine_DeleteNote"
	set notesTablePointeur to table view "notesTableView" of scroll view "notesScrollView" of window "Main"
	-- Le résultat "table view id 4 of scroll view id 3 of window id 1"
	
	set lesLignesSelectionner to selected data rows of notesTablePointeur
	-- Le résultat est la liste des adresses des lignes à supprimer --
	-- "{data row id 30 of data source id 12, data row id 31 of data source id 12}
	
	
	if (count of lesLignesSelectionner) > 0 then
		repeat with i from 1 to (count of lesLignesSelectionner)
			delete (item i of lesLignesSelectionner) --  c'est une liste
		end repeat
		set selected rows of notesTablePointeur to {0} -- Pour enlever le fond bleue
	else
		-- display dialog "Vous devez sélectionner au moins une rangée"
		set monMessage to localized string "YouMustSelectRows" from table "Localizable"
		display dialog monMessage buttons {cancel, OK} default button 2
		
	end if
end routine_DeleteNote ---------------------------------------------------





on routine_AddOneNote() --------- Ajout d'une Note - show window "Input" -------------
	-- Remise à blanc des champs d'entrées
	set the contents of text field "NomInput" of window "Input" to "theName"
	set the contents of text field "DescriptionInput" of window "Input" to "theDescription"
	set the contents of text field "DateInput" of window "Input" to current date
	set the contents of text field "PrixInput" of window "Input" to 12
	-- tell window "Input" to open - marche pas -
	show window "Input"
end routine_AddOneNote ---------------------------------------------------



on routine_AjouterInput() -------- Quand le bouton "ajouterInput" est cliqué --------
	set leNom to contents of text field "NomInput" of window "Input"
	set laDescription to contents of text field "DescriptionInput" of window "Input"
	set laDate to contents of text field "DateInput" of window "Input"
	set lePrix to contents of text field "PrixInput" of window "Input" as number
	set laCol5 to ""
	set LaCol6 to "" -- Pas dans la fenêtre INPUT
	
	stockerUneLigne(leNom, laDescription, laDate, lePrix, laCol5, LaCol6)
	
	-- Remise à blanc des champs d'entrées
	set the contents of text field "NomInput" of window "Input" to "theName"
	set the contents of text field "DescriptionInput" of window "Input" to "theDescription"
	set the contents of text field "DateInput" of window "Input" to current date
	set the contents of text field "PrixInput" of window "Input" to 14
	hide window "Input"
end routine_AjouterInput ---------------------------------------------------


(* ================================================ *)







(* ================= For Debug or Initialisation ================== *)



on Notes_Init_Data() ------------- Pour la première exécution ---------------------
	
	----------------------------- Liste initiale pour la démo --------------------------
	set ListeDeDemo to {{"Transmit", "FTP", date "mercredi 6 décembre 2006 0:00:00", 29, 95}, {"CDpedia", "Gestionnaire de CD", date "jeudi 11 octobre 2007 0:00:00", 16}, {"Coda", "Editeur de CSS & HTML", date "vendredi 7 décembre 2007 0:00:00", 69}}
	
	Creation_DataSource_Notes(ListeDeDemo) -- Create & load Data Source
	
	-- Notez pour la date, c'est xCode qui traduit 6/12/2006 en date longue
	-- La frappe initiale est {"Transmit", "FTP", date "6/12/2006", 29, 95}
	
end Notes_Init_Data ----------------------------------------------------------------------

(* ====================================================== *)
